@@ -15,6 +15,7 @@ import unittest
 
 from parameterized import parameterized
 import requests
+import urllib3
 
 from joppy.api import Api, JoplinKwargs
 from joppy import tools
@@ -98,6 +99,9 @@ class TestBase(unittest.TestCase):
 
     def setUp(self):
         super().setUp()
+
+        logging.debug(f"Test: {self.id()}")
+
         self.api = Api(token=API_TOKEN)
         # Note: Notes get deleted automatically.
         self.api.delete_all_notebooks()
@@ -116,7 +120,9 @@ class TestBase(unittest.TestCase):
         characters = string.printable
         for character in exclude:
             characters = characters.replace(character, "")
-        return "".join(random.choice(characters) for _ in range(length))
+        random_string = "".join(random.choice(characters) for _ in range(length))
+        logging.debug(f"Test: random string: {random_string}")
+        return random_string
 
     @staticmethod
     def is_id_valid(id_: str) -> bool:
@@ -349,17 +355,26 @@ class Note(TestBase):
 
     def test_move(self):
         """Move a note from one notebook to another."""
+        original_title = "test title"
+        original_body = "test body"
+
         notebook_1_id = self.api.add_notebook()
         notebook_2_id = self.api.add_notebook()
-        id_ = self.api.add_note(parent_id=notebook_1_id)
+        id_ = self.api.add_note(
+            parent_id=notebook_1_id, title=original_title, body=original_body
+        )
 
         note = self.api.get_note(id_=id_)
         self.assertEqual(note["parent_id"], notebook_1_id)
 
         self.api.modify_note(id_=id_, parent_id=notebook_2_id)
-        note = self.api.get_note(id_=id_)
+        note = self.api.get_note(id_=id_, fields="body,parent_id,title")
         self.assertEqual(note["parent_id"], notebook_2_id)
 
+        # Ensure the original properties aren't modified.
+        self.assertEqual(note["body"], original_body)
+        self.assertEqual(note["title"], original_title)
+
 
 class Notebook(TestBase):
     properties = [
@@ -367,6 +382,7 @@ class Notebook(TestBase):
         "id", "title", "created_time", "updated_time",
         "user_created_time", "user_updated_time", "encryption_cipher_text",
         "encryption_applied", "parent_id", "is_shared", "share_id",
+        "master_key_id", "icon",
         # fmt: on
     ]
     default_properties = ["id", "parent_id", "title"]
@@ -811,7 +827,7 @@ class Fuzz(TestBase):
                 self.api._request(method, path)
             except (
                 requests.exceptions.HTTPError,
-                requests.packages.urllib3.exceptions.LocationParseError,
+                urllib3.exceptions.LocationParseError,
             ):
                 pass
         self.api.ping()
